# Generated by Django 4.1.2 on 2023-02-21 08:33

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('snort', '0005_remove_snortrule_template_snortrule_is_template'),
    ]

    operations = [
        migrations.RenameField(
            model_name='snortrule',
            old_name='main_ref',
            new_name='document',
        ),
        migrations.RenameField(
            model_name='snortrule',
            old_name='request_ref',
            new_name='treatment',
        ),
        migrations.AlterField(
            model_name='snortruleviewarray',
            name='htmlId',
            field=models.CharField(blank=True, max_length=50),
        ),
    ]
